@@ -373,8 +373,8 @@ int vips_object_get_argument_priority( VipsObject *object, const char *name );
 		/* Input args are given inline, eg. ("factor", 12.0)  \
 		 * and must be collected. \
 		 */ \
-		g_value_init( &value, G_PARAM_SPEC_VALUE_TYPE( PSPEC ) ); \
-		G_VALUE_COLLECT( &value, AP, 0, &error ); \
+		G_VALUE_COLLECT_INIT( &value, \
+				G_PARAM_SPEC_VALUE_TYPE( PSPEC ), AP, 0, &error ); \
 		\
 		/* Don't bother with the error message. \
 		 */ \
